@@ -69,14 +69,7 @@ barbican_opts = [
     cfg.BoolOpt('verify_ssl',
                 default=True,
                 help='Specifies if insecure TLS (https) requests. If False, '
-                     'the server\'s certificate will not be validated, if '
-                     'True, we can set the verify_ssl_path config meanwhile.'),
-    cfg.StrOpt('verify_ssl_path',
-               default=None,
-               help='A path to a bundle or CA certs to check against, or '
-                    'None for requests to attempt to locate and use '
-                    'certificates which verify_ssh is True. If verify_ssl '
-                    'is False, this is ignored.'),
+                     'the server\'s certificate will not be validated'),
     cfg.StrOpt('barbican_endpoint_type',
                default='public',
                choices=['public', 'internal', 'admin'],
@@ -129,10 +122,8 @@ class BarbicanKeyManager(key_manager.KeyManager):
 
         try:
             auth = self._get_keystone_auth(context)
-            verify_ssl = self.conf.barbican.verify_ssl
-            verify_ssl_path = self.conf.barbican.verify_ssl_path
-            verify = verify_ssl and verify_ssl_path or verify_ssl
-            sess = session.Session(auth=auth, verify=verify)
+            sess = session.Session(auth=auth,
+                                   verify=self.conf.barbican.verify_ssl)
 
             self._barbican_endpoint = self._get_barbican_endpoint(auth, sess)
             self._barbican_client = barbican_client_import.Client(
@@ -153,7 +144,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
         return self._barbican_client
 
     def _get_keystone_auth(self, context):
-        if context.__class__.__name__ is 'KeystonePassword':
+        if context.__class__.__name__ == 'KeystonePassword':
             return identity.Password(
                 auth_url=context.auth_url,
                 username=context.username,
@@ -169,7 +160,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 project_domain_id=context.project_domain_id,
                 project_domain_name=context.project_domain_name,
                 reauthenticate=context.reauthenticate)
-        elif context.__class__.__name__ is 'KeystoneToken':
+        elif context.__class__.__name__ == 'KeystoneToken':
             return identity.Token(
                 auth_url=context.auth_url,
                 token=context.token,
@@ -183,7 +174,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 reauthenticate=context.reauthenticate)
         # this will be kept for oslo.context compatibility until
         # projects begin to use utils.credential_factory
-        elif context.__class__.__name__ is 'RequestContext':
+        elif context.__class__.__name__ == 'RequestContext':
             if getattr(context, 'get_auth_plugin', None):
                 return context.get_auth_plugin()
             else:
@@ -206,8 +197,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
             return barbican.barbican_endpoint
         elif getattr(auth, 'service_catalog', None):
             endpoint_data = auth.service_catalog.endpoint_data_for(
-                service_type='key-manager',
-                interface=barbican.barbican_endpoint_type)
+                service_type='key-manager')
             return endpoint_data.url
         else:
             service_parameters = {'service_type': 'key-manager',
